<?php

/**
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace loophp\phposinfo;

interface OsInfoInterface
{
    public static function arch(): string;

    public static function family(): string;

    public static function hostname(): string;

    public static function isApple(): bool;

    public static function isBSD(): bool;

    public static function isFamily(int|string $family): bool;

    public static function isOs(int|string $os): bool;

    public static function isUnix(): bool;

    public static function isWindows(): bool;

    public static function os(): string;

    /**
     * Register new constants.
     */
    public static function register(): void;

    public static function release(): string;

    /**
     * Get a unique ID for the host machine.
     *
     * Conforms to UUIDs generated by sebhildebrandt/systeminformation.
     *
     * @see https://github.com/sebhildebrandt/systeminformation/blob/master/lib/osinfo.js
     *
     * @return string|null
     *   The machine UUID.
     */
    public static function uuid(): ?string;

    public static function version(): string;
}
